@@ -2,7 +2,7 @@
 
 import gi
 gi.require_version('Gtk', '3.0')
-from gi.repository import Gio, Gtk, GObject, Gdk
+from gi.repository import Gio, Gtk
 
 from SettingsWidgets import SidePage
 from xapp.GSettingsWidgets import *
@@ -35,8 +35,10 @@ class Module:
             settings = page.add_section(_("Buttons"))
 
             button_options = []
-            button_options.append([":minimize,maximize,close", _("Traditional style (Right)")])
-            button_options.append(["close,minimize,maximize:", _("Mac style (Left)")])
+            button_options.append([":minimize,maximize,close", _("Right")])
+            button_options.append(["close,minimize,maximize:", _("Left")])
+            button_options.append([":close", _("Gnome")])
+            button_options.append(["close:minimize,maximize", _("Classic Mac")])
 
             widget = GSettingsComboBox(_("Buttons layout"), "org.cinnamon.desktop.wm.preferences", "button-layout", button_options, size_group=size_group)
             settings.add_row(widget)
